from setuptools import setup

setup(name='Jun_distributions',
      version='1.1',
      description='Gaussian and binomial distributions',
      packages=['Jun_distributions'],
      author = 'Jun Meng',
      author_email = 'jjunmeng@gmail.com',
      zip_safe=False)
